@@ -118,6 +118,8 @@ struct bgpevpn {
 
 	struct zebra_l2_vni_item zl2vni;
 
+	enum vxlan_flood_control vxlan_flood_ctrl;
+
 	QOBJ_FIELDS;
 };
 
@@ -422,13 +424,20 @@ static inline void ip_prefix_from_type5_prefix(const struct prefix_evpn *evp,
 	}
 }
 
-static inline int is_evpn_prefix_default(const struct prefix *evp)
+static inline bool is_evpn_prefix_default(const struct prefix *evp)
 {
 	if (evp->family != AF_EVPN)
-		return 0;
+		return false;
 
-	return ((evp->u.prefix_evpn.prefix_addr.ip_prefix_length  == 0) ?
-		1 : 0);
+	/*
+	 * EVPN default type-5 route
+	 * RD:[5]:[0]:[0.0.0.0/0]/352 or RD:[5]:[0]:[::/0]/352
+	 */
+	if ((evp->u.prefix_evpn.route_type == BGP_EVPN_IP_PREFIX_ROUTE) &&
+	    (evp->u.prefix_evpn.prefix_addr.ip_prefix_length == 0))
+		return true;
+
+	return false;
 }
 
 static inline void ip_prefix_from_type2_prefix(const struct prefix_evpn *evp,
@@ -673,8 +682,6 @@ static inline bool bgp_evpn_is_path_local(struct bgp *bgp,
 			&& pi->sub_type == BGP_ROUTE_STATIC);
 }
 
-extern struct zclient *zclient;
-
 extern void bgp_evpn_install_uninstall_default_route(struct bgp *bgp_vrf,
 						     afi_t afi, safi_t safi,
 						     bool add);
@@ -723,9 +730,8 @@ extern struct bgpevpn *bgp_evpn_new(struct bgp *bgp, vni_t vni,
 extern void bgp_evpn_free(struct bgp *bgp, struct bgpevpn *vpn);
 extern bool bgp_evpn_lookup_l3vni_l2vni_table(vni_t vni);
 extern int update_routes_for_vni(struct bgp *bgp, struct bgpevpn *vpn);
-extern void delete_evpn_route_entry(struct bgp *bgp, afi_t afi, safi_t safi,
-				    struct bgp_dest *dest,
-				    struct bgp_path_info **pi);
+extern struct bgp_path_info *delete_evpn_route_entry(struct bgp *bgp, afi_t afi, safi_t safi,
+						     struct bgp_dest *dest, uint32_t addpaht_id);
 int vni_list_cmp(void *p1, void *p2);
 extern int evpn_route_select_install(struct bgp *bgp, struct bgpevpn *vpn,
 				     struct bgp_dest *dest,
