@@ -169,9 +169,20 @@ int bgp_md5_set_prefix(struct bgp *bgp, struct prefix *p, const char *password)
 	/* Set or unset the password on the listen socket(s). */
 	frr_with_privs(&bgpd_privs) {
 		for (ALL_LIST_ELEMENTS_RO(bm->listen_sockets, node, listener))
-			if (listener->su.sa.sa_family == p->family
-			    && ((bgp->vrf_id == VRF_DEFAULT)
-				|| (listener->bgp == bgp))) {
+			/* Match listener socket for the incoming BGP instance if:
+			 * 1. Address family matches (IPv4/IPv6)
+			 * 2. AND either:
+			 *    - incoming BGP instance is in default VRF
+			 *      and listener has no BGP instance(default vrf)
+			 *    - OR listener's BGP instance matches the
+			 *      incoming BGP instance(non-default vrf)
+			 * [Note: listener->bgp is always NULL for default VRF.
+			 *        listener socket could be shared among multiple
+			 *        BGP instances within the same VRF.]
+			 */
+			if (listener->su.sa.sa_family == p->family &&
+			    ((bgp->vrf_id == VRF_DEFAULT && !listener->bgp) ||
+			     (listener->bgp == bgp))) {
 				prefix2sockunion(p, &su);
 				ret = bgp_md5_set_socket(listener->fd, &su,
 							 p->prefixlen,
@@ -510,7 +521,7 @@ static void bgp_accept(struct event *thread)
 			incoming->su_remote = sockunion_dup(&su);
 
 			if (bgp_set_socket_ttl(incoming) < 0) {
-				dynamic_peer->last_reset = PEER_DOWN_SOCKET_ERROR;
+				peer_set_last_reset(dynamic_peer, PEER_DOWN_SOCKET_ERROR);
 				zlog_err("%s: Unable to set min/max TTL on peer %s (dynamic), error received: %s(%d)",
 					 __func__, dynamic_peer->host, safe_strerror(errno), errno);
 				return;
@@ -535,6 +546,14 @@ static void bgp_accept(struct event *thread)
 					BGP_EVENT_ADD(incoming, TCP_connection_open);
 			}
 
+			return;
+		}
+	} else {
+		if (CHECK_FLAG(peer->flags, PEER_FLAG_DYNAMIC_NEIGHBOR)) {
+			zlog_debug("Received an open connection for a peering %s that we have not fully closed down yet",
+				   peer->host);
+			close(bgp_sock);
+
 			return;
 		}
 	}
@@ -608,7 +627,7 @@ static void bgp_accept(struct event *thread)
 	if (peer->bgp->router_id.s_addr == INADDR_ANY) {
 		zlog_warn("[Event] Incoming BGP connection rejected from %s due missing BGP identifier, set it with `bgp router-id`",
 			  peer->host);
-		peer->last_reset = PEER_DOWN_ROUTER_ID_ZERO;
+		peer_set_last_reset(peer, PEER_DOWN_ROUTER_ID_ZERO);
 		close(bgp_sock);
 		return;
 	}
@@ -674,7 +693,7 @@ static void bgp_accept(struct event *thread)
 		 * drop
 		 * existing established connection and move state to connect.
 		 */
-		peer->last_reset = PEER_DOWN_NSF_CLOSE_SESSION;
+		peer_set_last_reset(peer, PEER_DOWN_NSF_CLOSE_SESSION);
 
 		if (CHECK_FLAG(peer->flags, PEER_FLAG_GRACEFUL_RESTART) ||
 		    CHECK_FLAG(peer->flags, PEER_FLAG_GRACEFUL_RESTART_HELPER))
@@ -795,7 +814,7 @@ enum connect_result bgp_connect(struct peer_connection *connection)
 	assert(!CHECK_FLAG(connection->thread_flags, PEER_THREAD_READS_ON));
 
 	if (peer->bgp->router_id.s_addr == INADDR_ANY) {
-		peer->last_reset = PEER_DOWN_ROUTER_ID_ZERO;
+		peer_set_last_reset(peer, PEER_DOWN_ROUTER_ID_ZERO);
 		zlog_warn("%s: BGP identifier is missing for peer %s, set it with `bgp router-id`",
 			  __func__, peer->host);
 		return connect_error;
@@ -814,7 +833,7 @@ enum connect_result bgp_connect(struct peer_connection *connection)
 		connection->dir = CONNECTION_OUTGOING;
 	}
 	if (connection->fd < 0) {
-		peer->last_reset = PEER_DOWN_SOCKET_ERROR;
+		peer_set_last_reset(peer, PEER_DOWN_SOCKET_ERROR);
 		if (bgp_debug_neighbor_events(peer))
 			zlog_debug("%s: Failure to create socket for connection to %s, error received: %s(%d)",
 				   __func__, peer->host, safe_strerror(errno),
@@ -842,7 +861,7 @@ enum connect_result bgp_connect(struct peer_connection *connection)
 	bgp_update_setsockopt_tcp_keepalive(peer->bgp, connection->fd);
 
 	if (bgp_set_socket_ttl(peer->connection) < 0) {
-		peer->last_reset = PEER_DOWN_SOCKET_ERROR;
+		peer_set_last_reset(peer, PEER_DOWN_SOCKET_ERROR);
 		if (bgp_debug_neighbor_events(peer))
 			zlog_debug("%s: Failure to set socket ttl for connection to %s, error received: %s(%d)",
 				   __func__, peer->host, safe_strerror(errno),
@@ -877,7 +896,7 @@ enum connect_result bgp_connect(struct peer_connection *connection)
 
 	/* Update source bind. */
 	if (bgp_update_source(connection) < 0) {
-		peer->last_reset = PEER_DOWN_SOCKET_ERROR;
+		peer_set_last_reset(peer, PEER_DOWN_SOCKET_ERROR);
 		return connect_error;
 	}
 
