@@ -10,13 +10,18 @@
 
 #ifdef HAVE_SCRIPTING
 
-#include "frrlua.h"
+#include <lua.h>
 
 /*
  * Initialize scripting stuff.
  */
 void bgp_script_init(void);
 
+/*
+ * Note that the common lib/frrscript.h has forward-refs to some of these
+ * apis; if these change, please ensure those refs are updated too.
+ */
+
 /* Forward references */
 struct peer;
 struct attr;
