@@ -30,9 +30,11 @@ DECLARE_MGROUP(EIGRPD);
 #define EIGRP_TLV_MTR_VERSION 3 /* MTR TLVs with 32bit metric *Not Supported */
 #define EIGRP_TLV_SAF_VERSION 4 /* SAF TLVs with 64bit metric *Not Supported */
 
+//PREDECL_HASH(eigrp_master_hash);
+
 struct eigrp_master {
 	/* EIGRP instance. */
-	struct list *eigrp;
+	struct eigrp_master_hash_head eigrp;
 
 	/* EIGRP thread master. */
 	struct event_loop *master;
@@ -50,7 +52,7 @@ struct eigrp_master {
 };
 
 /* Extern variables. */
-extern struct zclient *zclient;
+extern struct zclient *eigrp_zclient;
 extern struct event_loop *master;
 extern struct eigrp_master *eigrp_om;
 extern struct zebra_privs_t eigrpd_privs;
@@ -64,4 +66,10 @@ extern struct eigrp *eigrp_get(uint16_t as, vrf_id_t vrf_id);
 extern struct eigrp *eigrp_lookup(vrf_id_t vrf_id);
 extern void eigrp_router_id_update(struct eigrp *eigrp);
 
+extern int eigrp_master_hash_cmp(const struct eigrp *a, const struct eigrp *b);
+extern uint32_t eigrp_master_hash_hash(const struct eigrp *a);
+
+DECLARE_HASH(eigrp_master_hash, struct eigrp, eigrp_item, eigrp_master_hash_cmp,
+	     eigrp_master_hash_hash);
+
 #endif /* _ZEBRA_EIGRPD_H */
