@@ -1,23 +1,10 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * IS-IS Rout(e)ing protocol - isis_dynhn.c
  *                             Dynamic hostname cache
  * Copyright (C) 2001,2002   Sampo Saaristo
  *                           Tampere University of Technology
  *                           Institute of Communications Engineering
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public Licenseas published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <zebra.h>
@@ -29,7 +16,7 @@
 #include "stream.h"
 #include "command.h"
 #include "if.h"
-#include "thread.h"
+#include "frrevent.h"
 
 #include "isisd/isis_constants.h"
 #include "isisd/isis_common.h"
@@ -42,14 +29,14 @@
 
 DEFINE_MTYPE_STATIC(ISISD, ISIS_DYNHN, "ISIS dyn hostname");
 
-static void dyn_cache_cleanup(struct thread *);
+static void dyn_cache_cleanup(struct event *);
 
 void dyn_cache_init(struct isis *isis)
 {
 	isis->dyn_cache = list_new();
 	if (!CHECK_FLAG(im->options, F_ISIS_UNIT_TEST))
-		thread_add_timer(master, dyn_cache_cleanup, isis, 120,
-				 &isis->t_dync_clean);
+		event_add_timer(master, dyn_cache_cleanup, isis, 120,
+				&isis->t_dync_clean);
 }
 
 void dyn_cache_finish(struct isis *isis)
@@ -57,7 +44,7 @@ void dyn_cache_finish(struct isis *isis)
 	struct listnode *node, *nnode;
 	struct isis_dynhn *dyn;
 
-	THREAD_OFF(isis->t_dync_clean);
+	event_cancel(&isis->t_dync_clean);
 
 	for (ALL_LIST_ELEMENTS(isis->dyn_cache, node, nnode, dyn)) {
 		list_delete_node(isis->dyn_cache, node);
@@ -67,14 +54,14 @@ void dyn_cache_finish(struct isis *isis)
 	list_delete(&isis->dyn_cache);
 }
 
-static void dyn_cache_cleanup(struct thread *thread)
+static void dyn_cache_cleanup(struct event *thread)
 {
 	struct listnode *node, *nnode;
 	struct isis_dynhn *dyn;
 	time_t now = time(NULL);
 	struct isis *isis = NULL;
 
-	isis = THREAD_ARG(thread);
+	isis = EVENT_ARG(thread);
 
 	isis->t_dync_clean = NULL;
 
@@ -85,7 +72,7 @@ static void dyn_cache_cleanup(struct thread *thread)
 		XFREE(MTYPE_ISIS_DYNHN, dyn);
 	}
 
-	thread_add_timer(master, dyn_cache_cleanup, isis, 120,
+	event_add_timer(master, dyn_cache_cleanup, isis, 120,
 			&isis->t_dync_clean);
 }
 
@@ -158,12 +145,10 @@ void dynhn_print_all(struct vty *vty, struct isis *isis)
 	vty_out(vty, "Level  System ID      Dynamic Hostname\n");
 	for (ALL_LIST_ELEMENTS_RO(isis->dyn_cache, node, dyn)) {
 		vty_out(vty, "%-7d", dyn->level);
-		vty_out(vty, "%-15s%-15s\n", sysid_print(dyn->id),
-			dyn->hostname);
+		vty_out(vty, "%pSY %-15s\n", dyn->id, dyn->hostname);
 	}
 
-	vty_out(vty, "     * %s %s\n", sysid_print(isis->sysid),
-		cmd_hostname_get());
+	vty_out(vty, "     * %pSY %s\n", isis->sysid, cmd_hostname_get());
 	return;
 }
 
