@@ -1,25 +1,10 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * Affinity map function.
  *
  * Copyright 2022 Hiroki Shirokura, LINE Corporation
  * Copyright 2022 Masakazu Asama
  * Copyright 2022 6WIND S.A.
- *
- * This file is part of Free Range Routing (FRR).
- *
- * FRR is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
- * later version.
- *
- * FRR is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <zebra.h>
@@ -127,3 +112,12 @@ void affinity_map_set_update_hook(void (*func)(const char *affmap_name,
 {
 	affinity_map_master.update_hook = func;
 }
+
+void affinity_map_terminate(void)
+{
+	struct affinity_map *map;
+	struct listnode *node, *nnode;
+
+	for (ALL_LIST_ELEMENTS(affinity_map_master.maps, node, nnode, map))
+		affinity_map_free(map);
+}
