@@ -159,6 +159,7 @@ enum node_type {
 	SRV6_ENCAP_NODE,		 /* SRv6 encapsulation node */
 	SRV6_SID_FORMATS_NODE,		 /* SRv6 SID formats config node */
 	SRV6_SID_FORMAT_USID_F3216_NODE,		 /* SRv6 uSID f3216 format config node */
+	SRV6_SID_FORMAT_USID_F4816_NODE,		 /* SRv6 uSID f4816 format config node */
 	SRV6_SID_FORMAT_UNCOMPRESSED_F4024_NODE,		 /* SRv6 uncompressed f4024 format config node */
 	VTY_NODE,		 /* Vty node. */
 	FPM_NODE,		 /* Dataplane FPM node. */
@@ -664,6 +665,8 @@ extern void cmd_show_lib_debugs(struct vty *vty);
 extern const struct frr_yang_module_info frr_host_cli_info;
 extern void host_cli_init(void);
 
+extern void log_cli_init(void);
+
 #ifdef __cplusplus
 }
 #endif
