@@ -54,7 +54,7 @@ static size_t darr_size(uint count, size_t esize)
 	return count * esize + sizeof(struct darr_metadata);
 }
 
-char *__darr_in_vsprintf(char **sp, bool concat, const char *fmt, va_list ap)
+char *_darr__in_vsprintf(char **sp, bool concat, const char *fmt, va_list ap)
 {
 	size_t inlen = concat ? darr_strlen(*sp) : 0;
 	size_t capcount = strlen(fmt) + MIN(inlen + 64, 128);
@@ -84,18 +84,18 @@ again:
 	return *sp;
 }
 
-char *__darr_in_sprintf(char **sp, bool concat, const char *fmt, ...)
+char *_darr__in_sprintf(char **sp, bool concat, const char *fmt, ...)
 {
 	va_list ap;
 
 	va_start(ap, fmt);
-	(void)__darr_in_vsprintf(sp, concat, fmt, ap);
+	(void)_darr__in_vsprintf(sp, concat, fmt, ap);
 	va_end(ap);
 	return *sp;
 }
 
 
-void *__darr_resize(void *a, uint count, size_t esize, struct memtype *mtype)
+void *_darr__resize(void *a, uint count, size_t esize, struct memtype *mtype)
 {
 	uint ncount = darr_next_count(count, esize);
 	size_t osz = (a == NULL) ? 0 : darr_size(darr_cap(a), esize);
@@ -115,14 +115,13 @@ void *__darr_resize(void *a, uint count, size_t esize, struct memtype *mtype)
 }
 
 
-void *__darr_insert_n(void *a, uint at, uint count, size_t esize, bool zero,
-		      struct memtype *mtype)
+void *_darr__insert_n(void *a, uint at, uint count, size_t esize, bool zero, struct memtype *mtype)
 {
 	struct darr_metadata *dm;
 	uint olen, nlen;
 
 	if (!a)
-		a = __darr_resize(NULL, at + count, esize, mtype);
+		a = _darr__resize(NULL, at + count, esize, mtype);
 	dm = (struct darr_metadata *)a - 1;
 	olen = dm->len;
 
@@ -137,7 +136,7 @@ void *__darr_insert_n(void *a, uint at, uint count, size_t esize, bool zero,
 		nlen = olen + count;
 
 	if (nlen > dm->cap) {
-		a = __darr_resize(a, nlen, esize, mtype);
+		a = _darr__resize(a, nlen, esize, mtype);
 		dm = (struct darr_metadata *)a - 1;
 	}
 
@@ -158,3 +157,73 @@ void *__darr_insert_n(void *a, uint at, uint count, size_t esize, bool zero,
 	return a;
 #undef _a_at
 }
+
+int _darr_search_floor(const void *a, size_t esize, const void *key, bool *equal,
+		       darr_search_cmpf cmpf)
+{
+	struct darr_metadata *dm;
+
+	if (equal)
+		*equal = false;
+
+	if (!a)
+		return -1;
+
+	dm = (struct darr_metadata *)a - 1;
+
+	int len = dm->len;
+	int low = 0, high = len - 1;
+	int floor = -1;
+
+#define _a_at(i) ((void *)((char *)a + ((i)*esize)))
+	while (low <= high) {
+		int mid = low + (high - low) / 2;
+		int cmp;
+
+		if (cmpf)
+			cmp = cmpf(_a_at(mid), key);
+		else
+			cmp = memcmp(_a_at(mid), key, esize);
+
+		if (!cmp) {
+			if (equal)
+				*equal = true;
+			return mid;
+		} else if (cmp < 0) {
+			floor = mid;
+			low = mid + 1;
+		} else {
+			high = mid - 1;
+		}
+	}
+
+	return floor;
+#undef _a_at
+}
+
+int _darr_search(const void *a, size_t esize, const void *key, darr_search_cmpf cmpf)
+{
+	bool equal;
+	int i;
+
+	i = _darr_search_floor(a, esize, key, &equal, cmpf);
+	if (!equal)
+		return -1;
+	return i;
+}
+
+uint _darr_search_ceil(const void *a, size_t esize, const void *key, bool *equal,
+		       darr_search_cmpf cmpf)
+{
+	uint i;
+
+	i = _darr_search_floor(a, esize, key, equal, cmpf);
+	if (*equal)
+		return i;
+	return i + 1;
+}
+
+int darr_strings_cmp(const char **a, const char *key)
+{
+	return strcmp(*a, key);
+}
