@@ -1,20 +1,7 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * Copyright (C) 2018  NetDEF, Inc.
  *                     Renato Westphal
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <zebra.h>
@@ -159,7 +146,7 @@ struct yang_translator *yang_translator_load(const char *path)
 	 */
 	assert(dnode);
 
-	family = yang_dnode_get_string(dnode, "./family");
+	family = yang_dnode_get_string(dnode, "family");
 	translator = yang_translator_find(family);
 	if (translator != NULL) {
 		flog_warn(EC_LIB_YANG_TRANSLATOR_LOAD,
@@ -179,7 +166,7 @@ struct yang_translator *yang_translator_load(const char *path)
 	RB_INSERT(yang_translators, &yang_translators, translator);
 
 	/* Initialize the translator libyang context. */
-	translator->ly_ctx = yang_ctx_new_setup(false, false);
+	translator->ly_ctx = yang_ctx_new_setup(false, false, false);
 	if (!translator->ly_ctx) {
 		flog_warn(EC_LIB_LIBYANG, "%s: ly_ctx_new() failed", __func__);
 		goto error;
@@ -195,7 +182,7 @@ struct yang_translator *yang_translator_load(const char *path)
 		tmodule =
 			XCALLOC(MTYPE_YANG_TRANSLATOR_MODULE, sizeof(*tmodule));
 
-		module_name = yang_dnode_get_string(set->dnodes[i], "./name");
+		module_name = yang_dnode_get_string(set->dnodes[i], "name");
 		tmodule->module = ly_ctx_load_module(translator->ly_ctx,
 						     module_name, NULL, NULL);
 		if (!tmodule->module) {
@@ -246,10 +233,10 @@ struct yang_translator *yang_translator_load(const char *path)
 		const struct lysc_node *snode_custom, *snode_native;
 
 		xpath_custom =
-			yang_dnode_get_string(set->dnodes[i], "./custom");
+			yang_dnode_get_string(set->dnodes[i], "custom");
 
-		snode_custom = lys_find_path(translator->ly_ctx, NULL,
-					     xpath_custom, 0);
+		snode_custom =
+			yang_find_snode(translator->ly_ctx, xpath_custom, 0);
 		if (!snode_custom) {
 			flog_warn(EC_LIB_YANG_TRANSLATOR_LOAD,
 				  "%s: unknown data path: %s", __func__,
@@ -259,9 +246,8 @@ struct yang_translator *yang_translator_load(const char *path)
 		}
 
 		xpath_native =
-			yang_dnode_get_string(set->dnodes[i], "./native");
-		snode_native =
-			lys_find_path(ly_native_ctx, NULL, xpath_native, 0);
+			yang_dnode_get_string(set->dnodes[i], "native");
+		snode_native = yang_find_snode(ly_native_ctx, xpath_native, 0);
 		if (!snode_native) {
 			flog_warn(EC_LIB_YANG_TRANSLATOR_LOAD,
 				  "%s: unknown data path: %s", __func__,
@@ -328,7 +314,7 @@ yang_translate_xpath(const struct yang_translator *translator, int dir,
 	else
 		ly_ctx = ly_native_ctx;
 
-	snode = lys_find_path(ly_ctx, NULL, xpath, 0);
+	snode = yang_find_snode(ly_ctx, xpath, 0);
 	if (!snode) {
 		flog_warn(EC_LIB_YANG_TRANSLATION_ERROR,
 			  "%s: unknown data path: %s", __func__, xpath);
@@ -341,8 +327,12 @@ yang_translate_xpath(const struct yang_translator *translator, int dir,
 	if (!mapping)
 		return YANG_TRANSLATE_NOTFOUND;
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+	/* processing format strings from mapping node... */
 	n = sscanf(xpath, mapping->xpath_from_fmt, keys[0], keys[1], keys[2],
 		   keys[3]);
+#pragma GCC diagnostic pop
 	if (n < 0) {
 		flog_warn(EC_LIB_YANG_TRANSLATION_ERROR,
 			  "%s: sscanf() failed: %s", __func__,
@@ -350,8 +340,12 @@ yang_translate_xpath(const struct yang_translator *translator, int dir,
 		return YANG_TRANSLATE_FAILURE;
 	}
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+	/* processing format strings from mapping node... */
 	snprintf(xpath, xpath_len, mapping->xpath_to_fmt, keys[0], keys[1],
 		 keys[2], keys[3]);
+#pragma GCC diagnostic pop
 
 	return YANG_TRANSLATE_SUCCESS;
 }
@@ -518,7 +512,7 @@ static unsigned int yang_module_nodes_count(const struct lys_module *module)
 
 void yang_translator_init(void)
 {
-	ly_translator_ctx = yang_ctx_new_setup(true, false);
+	ly_translator_ctx = yang_ctx_new_setup(true, false, false);
 	if (!ly_translator_ctx) {
 		flog_err(EC_LIB_LIBYANG, "%s: ly_ctx_new() failed", __func__);
 		exit(1);
