@@ -1,17 +1,6 @@
+// SPDX-License-Identifier: ISC
 /*
  * Copyright (c) 2015-21  David Lamparter, for NetDEF, Inc.
- *
- * Permission to use, copy, modify, and distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
- *
- * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
- * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
- * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
- * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
- * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
- * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
- * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
 /* when you work on this code, please install a fuzzer (e.g. AFL) and run
@@ -24,6 +13,9 @@
  */
 
 #include "zebra.h"
+#include <fcntl.h>
+
+#include "frrsendmmsg.h"
 
 #include "zlog_5424.h"
 
@@ -33,11 +25,11 @@
 #include "memory.h"
 #include "frrcu.h"
 #include "printfrr.h"
-#include "typerb.h"
+#include "lib/typesafe.h"
 #include "frr_pthread.h"
 #include "command.h"
 #include "monotime.h"
-#include "thread.h"
+#include "frrevent.h"
 
 #include "lib/version.h"
 #include "lib/lib_errors.h"
@@ -605,12 +597,13 @@ static void gmtime_assafe(time_t ts, struct tm *res)
 	if (ts >= 306) /* Jan 1 of next year */
 		res->tm_year++;
 
-	static unsigned int months[13] = {
+	static time_t months[13] = {
 		0, 31, 61, 92, 122, 153, 184, 214, 245, 275, 306, 337, 365,
 	};
+	const size_t month_max = array_size(months) - 1;
 
-	for (size_t i = 0; i < array_size(months); i++) {
-		if ((unsigned int)ts < months[i + 1]) {
+	for (size_t i = 0; i < month_max; i++) {
+		if (ts < months[i + 1]) {
 			res->tm_mon = ((i + 2) % 12);
 			res->tm_mday = 1 + ts - months[i];
 			break;
@@ -749,7 +742,8 @@ static void zlog_5424_cycle(struct zlog_cfg_5424 *zcf, int fd)
 		/* all of this is swapped in by zlog_target_replace() below,
 		 * the old target is RCU-freed afterwards.
 		 */
-		zt = zlog_target_clone(MTYPE_LOG_5424, &zcf->active->zt,
+		zt = zlog_target_clone(MTYPE_LOG_5424,
+				       zcf->active ? &zcf->active->zt : NULL,
 				       sizeof(*zlt));
 		zlt = container_of(zt, struct zlt_5424, zt);
 
@@ -789,7 +783,7 @@ static void zlog_5424_cycle(struct zlog_cfg_5424 *zcf, int fd)
 	}
 
 	old = zcf->active ? &zcf->active->zt : NULL;
-	old = zlog_target_replace(old, &zlt->zt);
+	old = zlog_target_replace(old, zlt ? &zlt->zt : NULL);
 	zcf->active = zlt;
 
 	/* oldt->fd == fd happens for zlog_5424_apply_meta() */
@@ -799,10 +793,10 @@ static void zlog_5424_cycle(struct zlog_cfg_5424 *zcf, int fd)
 	rcu_free(MTYPE_LOG_5424, oldt, zt.rcu_head);
 }
 
-static void zlog_5424_reconnect(struct thread *t)
+static void zlog_5424_reconnect(struct event *t)
 {
-	struct zlog_cfg_5424 *zcf = THREAD_ARG(t);
-	int fd = THREAD_FD(t);
+	struct zlog_cfg_5424 *zcf = EVENT_ARG(t);
+	int fd = EVENT_FD(t);
 	char dummy[256];
 	ssize_t ret;
 
@@ -810,8 +804,8 @@ static void zlog_5424_reconnect(struct thread *t)
 		ret = read(fd, dummy, sizeof(dummy));
 		if (ret > 0) {
 			/* logger is sending us something?!?! */
-			thread_add_read(t->master, zlog_5424_reconnect, zcf, fd,
-					&zcf->t_reconnect);
+			event_add_read(t->master, zlog_5424_reconnect, zcf, fd,
+				       &zcf->t_reconnect);
 			return;
 		}
 
@@ -887,10 +881,15 @@ static int zlog_5424_open(struct zlog_cfg_5424 *zcf, int sock_type)
 
 	switch (zcf->dst) {
 	case ZLOG_5424_DST_NONE:
-		break;
+		return -1;
 
 	case ZLOG_5424_DST_FD:
 		fd = dup(zcf->fd);
+		if (fd < 0) {
+			flog_err_sys(EC_LIB_SYSTEM_CALL,
+				     "failed to dup() log file descriptor: %m (FD limit too low?)");
+			return -1;
+		}
 
 		optlen = sizeof(sock_type);
 		if (!getsockopt(fd, SOL_SOCKET, SO_TYPE, &sock_type, &optlen)) {
@@ -901,7 +900,7 @@ static int zlog_5424_open(struct zlog_cfg_5424 *zcf, int sock_type)
 
 	case ZLOG_5424_DST_FIFO:
 		if (!zcf->filename)
-			break;
+			return -1;
 
 		if (!zcf->file_nocreate) {
 			frr_with_privs (lib_privs) {
@@ -914,15 +913,15 @@ static int zlog_5424_open(struct zlog_cfg_5424 *zcf, int sock_type)
 			if (err == 0)
 				do_chown = true;
 			else if (errno != EEXIST)
-				break;
+				return -1;
 		}
 
 		flags = O_NONBLOCK;
-		/* fallthru */
+		fallthrough;
 
 	case ZLOG_5424_DST_FILE:
 		if (!zcf->filename)
-			break;
+			return -1;
 
 		frr_with_privs (lib_privs) {
 			fd = open(zcf->filename, flags | O_WRONLY | O_APPEND |
@@ -934,7 +933,7 @@ static int zlog_5424_open(struct zlog_cfg_5424 *zcf, int sock_type)
 			flog_err_sys(EC_LIB_SYSTEM_CALL,
 				     "could not open log file %pSE: %m",
 				     zcf->filename);
-			break;
+			return -1;
 		}
 
 		frr_with_privs (lib_privs) {
@@ -962,11 +961,11 @@ static int zlog_5424_open(struct zlog_cfg_5424 *zcf, int sock_type)
 		flog_err_sys(EC_LIB_SYSTEM_CALL,
 			     "could not open or create log file %pSE: %m",
 			     zcf->filename);
-		break;
+		return -1;
 
 	case ZLOG_5424_DST_UNIX:
 		if (!zcf->filename)
-			break;
+			return -1;
 
 		memset(&sa, 0, sizeof(sa));
 		sa.sun_family = AF_UNIX;
@@ -998,6 +997,7 @@ static int zlog_5424_open(struct zlog_cfg_5424 *zcf, int sock_type)
 				"could not connect to log unix path %pSE: %m",
 				zcf->filename);
 			need_reconnect = true;
+			/* no return -1 here, trigger retry code below */
 		} else {
 			/* datagram sockets are connectionless, restarting
 			 * the receiver may lose some packets but will resume
@@ -1040,14 +1040,14 @@ static int zlog_5424_open(struct zlog_cfg_5424 *zcf, int sock_type)
 		assert(zcf->master);
 
 		if (fd != -1) {
-			thread_add_read(zcf->master, zlog_5424_reconnect, zcf,
-					fd, &zcf->t_reconnect);
+			event_add_read(zcf->master, zlog_5424_reconnect, zcf,
+				       fd, &zcf->t_reconnect);
 			zcf->reconn_backoff_cur = zcf->reconn_backoff;
 
 		} else {
-			thread_add_timer_msec(zcf->master, zlog_5424_reconnect,
-					      zcf, zcf->reconn_backoff_cur,
-					      &zcf->t_reconnect);
+			event_add_timer_msec(zcf->master, zlog_5424_reconnect,
+					     zcf, zcf->reconn_backoff_cur,
+					     &zcf->t_reconnect);
 
 			zcf->reconn_backoff_cur += zcf->reconn_backoff_cur / 2;
 			if (zcf->reconn_backoff_cur > zcf->reconn_backoff_max)
@@ -1063,7 +1063,7 @@ bool zlog_5424_apply_dst(struct zlog_cfg_5424 *zcf)
 {
 	int fd = -1;
 
-	thread_cancel(&zcf->t_reconnect);
+	event_cancel(&zcf->t_reconnect);
 
 	if (zcf->prio_min != ZLOG_DISABLED)
 		fd = zlog_5424_open(zcf, -1);
@@ -1077,9 +1077,17 @@ bool zlog_5424_apply_dst(struct zlog_cfg_5424 *zcf)
 
 bool zlog_5424_apply_meta(struct zlog_cfg_5424 *zcf)
 {
+	int fd;
+
 	frr_with_mutex (&zcf->cfg_mtx) {
 		if (zcf->active)
-			zlog_5424_cycle(zcf, zcf->active->fd);
+			fd = zcf->active->fd;
+		else if (zcf->prio_min != ZLOG_DISABLED)
+			fd = zlog_5424_open(zcf, -1);
+		else
+			fd = -1;
+		if (fd >= 0)
+			zlog_5424_cycle(zcf, fd);
 	}
 
 	return true;
@@ -1116,7 +1124,7 @@ bool zlog_5424_rotate(struct zlog_cfg_5424 *zcf)
 		if (!zcf->active)
 			return true;
 
-		thread_cancel(&zcf->t_reconnect);
+		event_cancel(&zcf->t_reconnect);
 
 		/* need to retain the socket type because it also influences
 		 * other fields (packets) and we can't atomically swap these
