@@ -33,6 +33,7 @@
 
 const char *mgmt_be_client_names[MGMTD_BE_CLIENT_ID_MAX + 1] = {
 	[MGMTD_BE_CLIENT_ID_TESTC] = "mgmtd-testc", /* always first */
+	[MGMTD_BE_CLIENT_ID_MGMTD] = "mgmtd",	    /* loopback */
 	[MGMTD_BE_CLIENT_ID_ZEBRA] = "zebra",
 #ifdef HAVE_RIPD
 	[MGMTD_BE_CLIENT_ID_RIPD] = "ripd",
@@ -68,6 +69,7 @@ static const char *const zebra_config_xpaths[] = {
 	"/frr-affinity-map:lib",
 	"/frr-filter:lib",
 	"/frr-host:host",
+	"/frr-logging:logging",
 	"/frr-route-map:lib",
 	"/frr-zebra:zebra",
 	"/frr-interface:lib",
@@ -83,6 +85,27 @@ static const char *const zebra_oper_xpaths[] = {
 	NULL,
 };
 
+static const char *const zebra_rpc_xpaths[] = {
+	"/frr-logging",
+	NULL,
+};
+
+/*
+ * MGMTD does not use config paths. Config is handled specially since it's own
+ * tree is modified directly when processing changes from the front end clients
+ */
+
+static const char *const mgmtd_oper_xpaths[] = {
+	"/frr-backend:clients",
+	NULL,
+};
+
+static const char *const mgmtd_rpc_xpaths[] = {
+	"/frr-logging",
+	NULL,
+};
+
+
 #ifdef HAVE_MGMTD_TESTC
 static const char *const mgmtd_testc_oper_xpaths[] = {
 	"/frr-backend:clients",
@@ -94,6 +117,7 @@ static const char *const mgmtd_testc_oper_xpaths[] = {
 static const char *const ripd_config_xpaths[] = {
 	"/frr-filter:lib",
 	"/frr-host:host",
+	"/frr-logging:logging",
 	"/frr-interface:lib/interface",
 	"/frr-ripd:ripd",
 	"/frr-route-map:lib",
@@ -109,6 +133,7 @@ static const char *const ripd_oper_xpaths[] = {
 };
 static const char *const ripd_rpc_xpaths[] = {
 	"/frr-ripd",
+	"/frr-logging",
 	NULL,
 };
 #endif
@@ -117,6 +142,7 @@ static const char *const ripd_rpc_xpaths[] = {
 static const char *const ripngd_config_xpaths[] = {
 	"/frr-filter:lib",
 	"/frr-host:host",
+	"/frr-logging:logging",
 	"/frr-interface:lib/interface",
 	"/frr-ripngd:ripngd",
 	"/frr-route-map:lib",
@@ -130,6 +156,7 @@ static const char *const ripngd_oper_xpaths[] = {
 };
 static const char *const ripngd_rpc_xpaths[] = {
 	"/frr-ripngd",
+	"/frr-logging",
 	NULL,
 };
 #endif
@@ -137,16 +164,20 @@ static const char *const ripngd_rpc_xpaths[] = {
 #ifdef HAVE_STATICD
 static const char *const staticd_config_xpaths[] = {
 	"/frr-host:host",
+	"/frr-logging:logging",
 	"/frr-vrf:lib",
 	"/frr-interface:lib",
 	"/frr-routing:routing/control-plane-protocols/control-plane-protocol/frr-staticd:staticd",
 	NULL,
 };
-
 static const char *const staticd_oper_xpaths[] = {
 	"/frr-backend:clients",
 	NULL,
 };
+static const char *const staticd_rpc_xpaths[] = {
+	"/frr-logging",
+	NULL,
+};
 #endif
 /* clang-format on */
 
@@ -164,6 +195,7 @@ static const char *const *be_client_config_xpaths[MGMTD_BE_CLIENT_ID_MAX] = {
 };
 
 static const char *const *be_client_oper_xpaths[MGMTD_BE_CLIENT_ID_MAX] = {
+	[MGMTD_BE_CLIENT_ID_MGMTD] = mgmtd_oper_xpaths,
 #ifdef HAVE_MGMTD_TESTC
 	[MGMTD_BE_CLIENT_ID_TESTC] = mgmtd_testc_oper_xpaths,
 #endif
@@ -183,12 +215,17 @@ static const char *const *be_client_notif_xpaths[MGMTD_BE_CLIENT_ID_MAX] = {
 };
 
 static const char *const *be_client_rpc_xpaths[MGMTD_BE_CLIENT_ID_MAX] = {
+	[MGMTD_BE_CLIENT_ID_MGMTD] = mgmtd_rpc_xpaths,
 #ifdef HAVE_RIPD
 	[MGMTD_BE_CLIENT_ID_RIPD] = ripd_rpc_xpaths,
 #endif
 #ifdef HAVE_RIPNGD
 	[MGMTD_BE_CLIENT_ID_RIPNGD] = ripngd_rpc_xpaths,
 #endif
+#ifdef HAVE_STATICD
+	[MGMTD_BE_CLIENT_ID_STATICD] = staticd_rpc_xpaths,
+#endif
+	[MGMTD_BE_CLIENT_ID_ZEBRA] = zebra_rpc_xpaths,
 };
 
 /*
@@ -213,6 +250,14 @@ static struct mgmt_be_adapters_head mgmt_be_adapters;
 static struct mgmt_be_client_adapter
 	*mgmt_be_adapters_by_id[MGMTD_BE_CLIENT_ID_MAX];
 
+/*
+ * Mgmtd has it's own special "interested-in" xpath maps since it's not actually
+ * a backend client of itself.
+ */
+static const char *const mgmtd_config_xpaths[] = {
+	"/frr-logging:logging",
+};
+
 
 /* Forward declarations */
 static void
@@ -452,7 +497,8 @@ int mgmt_be_send_txn_req(struct mgmt_be_client_adapter *adapter, uint64_t txn_id
 	msg->refer_id = txn_id;
 	msg->create = create;
 
-	_dbg("Sending TXN_REQ to '%s' txn-id: %" PRIu64, adapter->name, txn_id);
+	_dbg("Sending TXN_REQ to '%s' to %s txn-id: %Lu", adapter->name,
+	     create ? "create" : "delete", txn_id);
 
 	ret = mgmt_msg_native_send_msg(adapter->conn, msg, false);
 	mgmt_msg_native_free_msg(msg);
@@ -651,23 +697,23 @@ static void be_adapter_handle_native_msg(struct mgmt_be_client_adapter *adapter,
 
 	case MGMT_MSG_CODE_ERROR:
 		error_msg = (typeof(error_msg))msg;
-		_dbg("Got ERROR from '%s' txn-id %" PRIx64, adapter->name, msg->refer_id);
+		_dbg("Got ERROR from '%s' txn-id %Lu", adapter->name, msg->refer_id);
 
 		/* Forward the reply to the txn module */
 		mgmt_txn_notify_error(adapter, msg->refer_id, msg->req_id,
 				      error_msg->error, error_msg->errstr);
-
+		/* We may have lost our connection and adapter at this point */
 		break;
 	case MGMT_MSG_CODE_TREE_DATA:
 		/* tree data from a backend client */
-		_dbg("Got TREE_DATA from '%s' txn-id %" PRIx64, adapter->name, msg->refer_id);
+		_dbg("Got TREE_DATA from '%s' txn-id %" PRIu64, adapter->name, msg->refer_id);
 
 		/* Forward the reply to the txn module */
 		mgmt_txn_notify_tree_data_reply(adapter, (struct mgmt_msg_tree_data *)msg, msg_len);
 		break;
 	case MGMT_MSG_CODE_RPC_REPLY:
 		/* RPC reply from a backend client */
-		_dbg("Got RPC_REPLY from '%s' txn-id %" PRIx64, adapter->name, msg->refer_id);
+		_dbg("Got RPC_REPLY from '%s' txn-id %" PRIu64, adapter->name, msg->refer_id);
 
 		/* Forward the reply to the txn module */
 		mgmt_txn_notify_rpc_reply(adapter, (struct mgmt_msg_rpc_reply *)msg, msg_len);
@@ -935,6 +981,20 @@ uint64_t mgmt_be_interested_clients(const char *xpath,
 	return clients;
 }
 
+bool mgmt_is_mgmtd_interested(const char *xpath)
+{
+	const char *const *match = mgmtd_config_xpaths;
+	const char *const *ematch = match + array_size(mgmtd_config_xpaths);
+
+	for (; match < ematch; match++) {
+		if (mgmt_be_xpath_prefix(*match, xpath)) {
+			_dbg("mgmtd: subscribed to %s", xpath);
+			return true;
+		}
+	}
+	return false;
+}
+
 /**
  * Return true if `client_id` is interested in `xpath` for `config`
  * or oper (!`config`).
