@@ -20,13 +20,8 @@ DECLARE_MTYPE(MGMTD_FE_ADPATER);
 DECLARE_MTYPE(MGMTD_FE_SESSION);
 DECLARE_MTYPE(MGMTD_TXN);
 DECLARE_MTYPE(MGMTD_TXN_REQ);
-DECLARE_MTYPE(MGMTD_TXN_SETCFG_REQ);
 DECLARE_MTYPE(MGMTD_TXN_COMMCFG_REQ);
-DECLARE_MTYPE(MGMTD_TXN_GETDATA_REQ);
-DECLARE_MTYPE(MGMTD_TXN_GETDATA_REPLY);
 DECLARE_MTYPE(MGMTD_TXN_GETTREE_REQ);
 DECLARE_MTYPE(MGMTD_TXN_RPC_REQ);
-DECLARE_MTYPE(MGMTD_TXN_CFG_BATCH);
-DECLARE_MTYPE(MGMTD_BE_ADAPTER_MSG_BUF);
 DECLARE_MTYPE(MGMTD_CMT_INFO);
 #endif /* _FRR_MGMTD_MEMORY_H */
