@@ -1,23 +1,8 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * OSPF version 2  Interface State Machine.
  *   From RFC2328 [OSPF Version 2]
  * Copyright (C) 1999 Toshiaki Takada
- *
- * This file is part of GNU Zebra.
- *
- * GNU Zebra is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
- * later version.
- *
- * GNU Zebra is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef _ZEBRA_OSPF_ISM_H
@@ -54,15 +39,15 @@
 			oi->on_write_q = 1;                                    \
 		}                                                              \
 		if (!list_isempty((O)->oi_write_q))                            \
-			thread_add_write(master, ospf_write, (O), (O)->fd,     \
-					 &(O)->t_write);                       \
+			event_add_write(master, ospf_write, (O), (O)->fd,      \
+					&(O)->t_write);                        \
 	} while (0)
 
 /* Macro for OSPF ISM timer turn on. */
-#define OSPF_ISM_TIMER_ON(T, F, V) thread_add_timer(master, (F), oi, (V), &(T))
+#define OSPF_ISM_TIMER_ON(T, F, V) event_add_timer(master, (F), oi, (V), &(T))
 
 #define OSPF_ISM_TIMER_MSEC_ON(T, F, V)                                        \
-	thread_add_timer_msec(master, (F), oi, (V), &(T))
+	event_add_timer_msec(master, (F), oi, (V), &(T))
 
 /* convenience macro to set hello timer correctly, according to
  * whether fast-hello is set or not
@@ -80,16 +65,16 @@
 
 /* Macro for OSPF schedule event. */
 #define OSPF_ISM_EVENT_SCHEDULE(I, E)                                          \
-	thread_add_event(master, ospf_ism_event, (I), (E), NULL)
+	event_add_event(master, ospf_ism_event, (I), (E), NULL)
 
 /* Macro for OSPF execute event. */
 #define OSPF_ISM_EVENT_EXECUTE(I, E)                                           \
-	thread_execute(master, ospf_ism_event, (I), (E))
+	event_execute(master, ospf_ism_event, (I), (E), NULL)
 
 /* Prototypes. */
-extern void ospf_ism_event(struct thread *thread);
+extern void ospf_ism_event(struct event *thread);
 extern void ism_change_status(struct ospf_interface *, int);
-extern void ospf_hello_timer(struct thread *thread);
+extern void ospf_hello_timer(struct event *thread);
 extern int ospf_dr_election(struct ospf_interface *oi);
 
 DECLARE_HOOK(ospf_ism_change,
