@@ -1040,6 +1040,10 @@ int pim_if_del_vif(struct interface *ifp)
 		return -1;
 	}
 
+	if (PIM_DEBUG_ZEBRA)
+		zlog_debug("%s: vif_index=%d  on interface %s ifindex=%d", __func__,
+			   pim_ifp->mroute_vif_index, ifp->name, ifp->ifindex);
+
 	/* if the device was a pim_vxlan iif/oif update vxlan mroute entries */
 	pim_vxlan_del_vif(ifp);
 
@@ -1716,6 +1720,7 @@ void pim_if_create_pimreg(struct pim_instance *pim)
 			snprintf(pimreg_name, sizeof(pimreg_name), PIMREG "%u",
 				 pim->vrf->data.l.table_id);
 
+		pim_reg_sock_bind(pim);
 		pim->regiface = if_get_by_name(pimreg_name, pim->vrf->vrf_id,
 					       pim->vrf->name);
 		pim->regiface->ifindex = PIM_OIF_PIM_REGISTER_VIF;
@@ -1887,6 +1892,13 @@ static int pim_ifp_up(struct interface *ifp)
 	*/
 	pim_if_addr_add_all(ifp);
 
+	/*pimreg interface might not be created in pim_ifp_create as
+	 * operational state may  be down at that moment, create one now if
+	 * not created.
+	 */
+	if (if_is_operative(ifp) && (!pim->regiface))
+		pim_if_create_pimreg(pim);
+
 	/*
 	 * If we have a pimreg device callback and it's for a specific
 	 * table set the master appropriately
