@@ -13,7 +13,7 @@ void igmp_v2_send_query(struct gm_group *group, int fd, const char *ifname,
 			struct in_addr group_addr,
 			int query_max_response_time_dsec);
 
-int igmp_v2_recv_report(struct gm_sock *igmp, struct in_addr from,
+int igmp_v2_recv_report(struct gm_sock *igmp, struct in_addr from, struct in_addr to,
 			const char *from_str, char *igmp_msg, int igmp_msg_len);
 
 int igmp_v2_recv_leave(struct gm_sock *igmp, struct ip *ip_hdr,
