@@ -436,6 +436,7 @@ static void pim_msdp_pkt_sa_gen(struct pim_instance *pim,
 			if (pim_msdp_log_sa_events(pim))
 				zlog_info("MSDP peer %pI4 filter SA out %s", &mp->peer, sa->sg_str);
 
+			mp->acl_out_count++;
 			continue;
 		}
 
@@ -498,6 +499,7 @@ void pim_msdp_pkt_sa_tx_one(struct pim_msdp_sa *sa)
 			if (pim_msdp_log_sa_events(sa->pim))
 				zlog_info("MSDP peer %pI4 filter SA out %s", &mp->peer, sa->sg_str);
 
+			mp->acl_out_count++;
 			continue;
 		}
 
@@ -531,6 +533,7 @@ void pim_msdp_pkt_sa_tx_one_to_one_peer(struct pim_msdp_peer *mp,
 			zlog_info("MSDP peer %pI4 filter SA out (%pI4, %pI4)", &mp->peer,
 				  &sa.sg.src, &sa.sg.grp);
 
+		mp->acl_out_count++;
 		return;
 	}
 
@@ -590,6 +593,8 @@ static void pim_msdp_pkt_sa_rx_one(struct pim_msdp_peer *mp, struct in_addr rp)
 			if (pim_msdp_log_sa_events(mp->pim))
 				zlog_info("MSDP peer %pI4 filter SA in (%pI4, %pI4)", &mp->peer,
 					  &sg.src, &sg.grp);
+
+			mp->acl_in_count++;
 			return;
 		}
 	}
