@@ -239,7 +239,7 @@ void pim_vxlan_update_sg_reg_state(struct pim_instance *pim,
 			zlog_debug("Received Register stop for %s",
 				   vxlan_sg->sg_str);
 
-		EVENT_OFF(vxlan_sg->null_register);
+		event_cancel(&vxlan_sg->null_register);
 		pim_vxlan_del_work(vxlan_sg);
 	}
 }
@@ -253,7 +253,7 @@ static void pim_vxlan_work_timer_cb(struct event *t)
 /* global 1second timer used for periodic processing */
 static void pim_vxlan_work_timer_setup(bool start)
 {
-	EVENT_OFF(vxlan_info.work_timer);
+	event_cancel(&vxlan_info.work_timer);
 	if (start)
 		event_add_timer(router->master, pim_vxlan_work_timer_cb, NULL,
 				PIM_VXLAN_WORK_TIME, &vxlan_info.work_timer);
@@ -300,7 +300,7 @@ static void pim_vxlan_orig_mr_up_del(struct pim_vxlan_sg *vxlan_sg)
 		 * if there are no other references.
 		 */
 		if (PIM_UPSTREAM_FLAG_TEST_SRC_STREAM(up->flags)) {
-			EVENT_OFF(up->t_ka_timer);
+			event_cancel(&up->t_ka_timer);
 			up = pim_upstream_keep_alive_timer_proc(up);
 		} else {
 			/* this is really unexpected as we force vxlan
@@ -842,7 +842,7 @@ static void pim_vxlan_sg_del_item(struct pim_vxlan_sg *vxlan_sg)
 {
 	vxlan_sg->flags |= PIM_VXLAN_SGF_DEL_IN_PROG;
 
-	EVENT_OFF(vxlan_sg->null_register);
+	event_cancel(&vxlan_sg->null_register);
 	pim_vxlan_del_work(vxlan_sg);
 
 	if (pim_vxlan_is_orig_mroute(vxlan_sg))
@@ -946,8 +946,6 @@ void pim_vxlan_mlag_update(bool enable, bool peer_state, uint32_t role,
 
 	if (enable)
 		vxlan_mlag.flags |= PIM_VXLAN_MLAGF_ENABLED;
-	else
-		vxlan_mlag.flags &= ~PIM_VXLAN_MLAGF_ENABLED;
 
 	if (vxlan_mlag.peerlink_rif != peerlink_rif)
 		vxlan_mlag.peerlink_rif = peerlink_rif;
@@ -959,11 +957,15 @@ void pim_vxlan_mlag_update(bool enable, bool peer_state, uint32_t role,
 	/* process changes */
 	if (vxlan_mlag.peerlink_rif)
 		pim_ifp = (struct pim_interface *)vxlan_mlag.peerlink_rif->info;
-	if ((vxlan_mlag.flags & PIM_VXLAN_MLAGF_ENABLED) &&
-			pim_ifp && (pim_ifp->mroute_vif_index > 0))
+	if (enable && pim_ifp && (pim_ifp->mroute_vif_index > 0))
 		pim_vxlan_set_peerlink_rif(pim, peerlink_rif);
-	else
+	else {
 		pim_vxlan_set_peerlink_rif(pim, NULL);
+
+		/*unset should be done only after peerlinks rif are unset*/
+		if (!enable)
+			vxlan_mlag.flags &= ~PIM_VXLAN_MLAGF_ENABLED;
+	}
 }
 
 /****************************** misc callbacks *******************************/
@@ -1249,9 +1251,14 @@ void pim_vxlan_exit(struct pim_instance *pim)
 {
 	hash_clean_and_free(&pim->vxlan.sg_hash,
 			    (void (*)(void *))pim_vxlan_sg_del_item);
+}
 
-	if (vxlan_info.work_list)
+void pim_vxlan_work_list_delete(void)
+{
+	if (vxlan_info.work_list) {
 		list_delete(&vxlan_info.work_list);
+		UNSET_FLAG(vxlan_info.flags, PIM_VXLANF_WORK_INITED);
+	}
 }
 
 void pim_vxlan_terminate(void)
