@@ -137,7 +137,7 @@ static void rip_garbage_collect(struct event *t)
 	rinfo = EVENT_ARG(t);
 
 	/* Off timeout timer. */
-	EVENT_OFF(rinfo->t_timeout);
+	event_cancel(&rinfo->t_timeout);
 
 	/* Get route_node pointer. */
 	rp = rinfo->rp;
@@ -249,14 +249,14 @@ struct rip_info *rip_ecmp_replace(struct rip *rip, struct rip_info *rinfo_new)
 		if (tmp_rinfo == rinfo)
 			continue;
 
-		EVENT_OFF(tmp_rinfo->t_timeout);
-		EVENT_OFF(tmp_rinfo->t_garbage_collect);
+		event_cancel(&tmp_rinfo->t_timeout);
+		event_cancel(&tmp_rinfo->t_garbage_collect);
 		list_delete_node(list, node);
 		rip_info_free(tmp_rinfo);
 	}
 
-	EVENT_OFF(rinfo->t_timeout);
-	EVENT_OFF(rinfo->t_garbage_collect);
+	event_cancel(&rinfo->t_timeout);
+	event_cancel(&rinfo->t_garbage_collect);
 	memcpy(rinfo, rinfo_new, sizeof(struct rip_info));
 
 	if (rip_route_rte(rinfo)) {
@@ -282,15 +282,21 @@ struct rip_info *rip_ecmp_replace(struct rip *rip, struct rip_info *rinfo_new)
  */
 struct rip_info *rip_ecmp_delete(struct rip *rip, struct rip_info *rinfo)
 {
-	struct route_node *rp = rinfo->rp;
-	struct list *list = (struct list *)rp->info;
+	struct route_node *rp;
+	struct list *list;
 
-	EVENT_OFF(rinfo->t_timeout);
+	if (rinfo == NULL)
+		return NULL;
+
+	rp = rinfo->rp;
+	list = (struct list *)rp->info;
+
+	event_cancel(&rinfo->t_timeout);
 
 	if (listcount(list) > 1) {
 		/* Some other ECMP entries still exist. Just delete this entry.
 		 */
-		EVENT_OFF(rinfo->t_garbage_collect);
+		event_cancel(&rinfo->t_garbage_collect);
 		listnode_delete(list, rinfo);
 		if (rip_route_rte(rinfo)
 		    && CHECK_FLAG(rinfo->flags, RIP_RTF_FIB))
@@ -336,7 +342,7 @@ static void rip_timeout(struct event *t)
 static void rip_timeout_update(struct rip *rip, struct rip_info *rinfo)
 {
 	if (rinfo->metric != RIP_METRIC_INFINITY) {
-		EVENT_OFF(rinfo->t_timeout);
+		event_cancel(&rinfo->t_timeout);
 		event_add_timer(master, rip_timeout, rinfo, rip->timeout_time,
 				&rinfo->t_timeout);
 	}
@@ -681,8 +687,8 @@ static void rip_rte_process(struct rte *rte, struct sockaddr_in *from,
 					assert(newinfo.metric
 					       != RIP_METRIC_INFINITY);
 
-					EVENT_OFF(rinfo->t_timeout);
-					EVENT_OFF(rinfo->t_garbage_collect);
+					event_cancel(&rinfo->t_timeout);
+					event_cancel(&rinfo->t_garbage_collect);
 					memcpy(rinfo, &newinfo,
 					       sizeof(struct rip_info));
 					rip_timeout_update(rip, rinfo);
@@ -800,27 +806,7 @@ static void rip_packet_dump(struct rip_packet *packet, int size,
    check net 0 because we accept default route. */
 static int rip_destination_check(struct in_addr addr)
 {
-	uint32_t destination;
-
-	/* Convert to host byte order. */
-	destination = ntohl(addr.s_addr);
-
-	if (IPV4_NET127(destination))
-		return 0;
-
-	/* Net 0 may match to the default route. */
-	if (IPV4_NET0(destination) && destination != 0)
-		return 0;
-
-	/* Unicast address must belong to class A, B, C. */
-	if (IN_CLASSA(destination))
-		return 1;
-	if (IN_CLASSB(destination))
-		return 1;
-	if (IN_CLASSC(destination))
-		return 1;
-
-	return 0;
+	return ipv4_unicast_valid(&addr);
 }
 
 /* RIP version 2 authentication. */
@@ -1645,7 +1631,7 @@ void rip_redistribute_delete(struct rip *rip, int type, int sub_type,
 				RIP_TIMER_ON(rinfo->t_garbage_collect,
 					     rip_garbage_collect,
 					     rip->garbage_time);
-				EVENT_OFF(rinfo->t_timeout);
+				event_cancel(&rinfo->t_timeout);
 				rinfo->flags |= RIP_RTF_CHANGED;
 
 				if (IS_RIP_DEBUG_EVENT)
@@ -2536,7 +2522,7 @@ static void rip_update(struct event *t)
 
 	/* Triggered updates may be suppressed if a regular update is due by
 	   the time the triggered update would be sent. */
-	EVENT_OFF(rip->t_triggered_interval);
+	event_cancel(&rip->t_triggered_interval);
 	rip->trigger = 0;
 
 	/* Register myself. */
@@ -2583,7 +2569,7 @@ static void rip_triggered_update(struct event *t)
 	int interval;
 
 	/* Cancel interval timer. */
-	EVENT_OFF(rip->t_triggered_interval);
+	event_cancel(&rip->t_triggered_interval);
 	rip->trigger = 0;
 
 	/* Logging triggered update. */
@@ -2633,7 +2619,7 @@ void rip_redistribute_withdraw(struct rip *rip, int type)
 		rinfo->metric = RIP_METRIC_INFINITY;
 		RIP_TIMER_ON(rinfo->t_garbage_collect, rip_garbage_collect,
 			     rip->garbage_time);
-		EVENT_OFF(rinfo->t_timeout);
+		event_cancel(&rinfo->t_timeout);
 		rinfo->flags |= RIP_RTF_CHANGED;
 
 		if (IS_RIP_DEBUG_EVENT) {
@@ -2716,12 +2702,9 @@ struct rip *rip_create(const char *vrf_name, struct vrf *vrf, int socket)
 		yang_get_default_uint8("%s/distance/default", RIP_INSTANCE);
 	rip->passive_default =
 		yang_get_default_bool("%s/passive-default", RIP_INSTANCE);
-	rip->garbage_time = yang_get_default_uint32("%s/timers/flush-interval",
-						    RIP_INSTANCE);
-	rip->timeout_time = yang_get_default_uint32(
-		"%s/timers/holddown-interval", RIP_INSTANCE);
-	rip->update_time = yang_get_default_uint32("%s/timers/update-interval",
-						   RIP_INSTANCE);
+	rip->garbage_time = yang_get_default_uint16("%s/timers/flush-interval", RIP_INSTANCE);
+	rip->timeout_time = yang_get_default_uint16("%s/timers/holddown-interval", RIP_INSTANCE);
+	rip->update_time = yang_get_default_uint16("%s/timers/update-interval", RIP_INSTANCE);
 	rip->version_send =
 		yang_get_default_enum("%s/version/send", RIP_INSTANCE);
 	rip->version_recv =
@@ -2844,7 +2827,7 @@ void rip_event(struct rip *rip, enum rip_event event, int sock)
 		event_add_read(master, rip_read, rip, sock, &rip->t_read);
 		break;
 	case RIP_UPDATE_EVENT:
-		EVENT_OFF(rip->t_update);
+		event_cancel(&rip->t_update);
 		jitter = rip_update_jitter(rip->update_time);
 		event_add_timer(master, rip_update, rip,
 				sock ? 2 : rip->update_time + jitter,
@@ -2969,8 +2952,8 @@ void rip_ecmp_disable(struct rip *rip)
 			if (tmp_rinfo == rinfo)
 				continue;
 
-			EVENT_OFF(tmp_rinfo->t_timeout);
-			EVENT_OFF(tmp_rinfo->t_garbage_collect);
+			event_cancel(&tmp_rinfo->t_timeout);
+			event_cancel(&tmp_rinfo->t_garbage_collect);
 			list_delete_node(list, node);
 			rip_info_free(tmp_rinfo);
 		}
@@ -3524,8 +3507,8 @@ static void rip_instance_disable(struct rip *rip)
 			rip_zebra_ipv4_delete(rip, rp);
 
 		for (ALL_LIST_ELEMENTS_RO(list, listnode, rinfo)) {
-			EVENT_OFF(rinfo->t_timeout);
-			EVENT_OFF(rinfo->t_garbage_collect);
+			event_cancel(&rinfo->t_timeout);
+			event_cancel(&rinfo->t_garbage_collect);
 			rip_info_free(rinfo);
 		}
 		list_delete(&list);
@@ -3537,12 +3520,12 @@ static void rip_instance_disable(struct rip *rip)
 	rip_redistribute_disable(rip);
 
 	/* Cancel RIP related timers. */
-	EVENT_OFF(rip->t_update);
-	EVENT_OFF(rip->t_triggered_update);
-	EVENT_OFF(rip->t_triggered_interval);
+	event_cancel(&rip->t_update);
+	event_cancel(&rip->t_triggered_update);
+	event_cancel(&rip->t_triggered_interval);
 
 	/* Cancel read thread. */
-	EVENT_OFF(rip->t_read);
+	event_cancel(&rip->t_read);
 
 	/* Close RIP socket. */
 	close(rip->sock);
