@@ -33,7 +33,7 @@ static void ripng_zebra_ipv6_send(struct ripng *ripng, struct agg_node *rp,
 	uint32_t count = 0;
 	const struct prefix *p = agg_node_get_prefix(rp);
 
-	memset(&api, 0, sizeof(api));
+	zapi_route_init(&api);
 	api.vrf_id = ripng->vrf->vrf_id;
 	api.type = ZEBRA_ROUTE_RIPNG;
 	api.safi = SAFI_UNICAST;
@@ -44,6 +44,8 @@ static void ripng_zebra_ipv6_send(struct ripng *ripng, struct agg_node *rp,
 		if (count >= zebra_ecmp_count)
 			break;
 		api_nh = &api.nexthops[count];
+		zapi_nexthop_init(api_nh);
+
 		api_nh->vrf_id = ripng->vrf->vrf_id;
 		api_nh->gate.ipv6 = rinfo->nexthop;
 		api_nh->ifindex = rinfo->ifindex;
