@@ -16,15 +16,14 @@ extern "C" {
  * us call this function to find the nexthop we are tracking so it
  * can be installed or removed.
  *
- * sp -> The route we are looking at.  If NULL then look at all
- *       routes.
+ * sp + ssrc_p -> The route we are looking at.  If NULL then look at all routes.
  * nhp -> The nexthop that is being tracked.
  * nh_num -> number of valid nexthops.
  * afi -> The afi we are working in.
  * vrf_id -> The vrf the nexthop is in.
  */
-extern void static_nht_update(struct prefix *sp, struct prefix *nhp,
-			      uint32_t nh_num, afi_t afi, safi_t safi,
+extern void static_nht_update(const struct prefix *sp, const struct prefix *ssrc_p,
+			      struct prefix *nhp, uint32_t nh_num, afi_t afi, safi_t safi,
 			      vrf_id_t vrf_id);
 
 /*
@@ -35,11 +34,10 @@ extern void static_nht_reset_start(struct prefix *nhp, afi_t afi, safi_t safi,
 				   vrf_id_t nh_vrf_id);
 
 /*
- * For the given prefix, sp, mark it as in a particular state
+ * For the given prefix, sp + ssrc_p, mark it as in a particular state
  */
-extern void static_nht_mark_state(struct prefix *sp, safi_t safi,
-				  vrf_id_t vrf_id,
-				  enum static_install_states state);
+extern void static_nht_mark_state(const struct prefix *sp, const struct prefix *ssrc_p, safi_t safi,
+				  vrf_id_t vrf_id, enum static_install_states state);
 
 /*
  * For the given nexthop, returns the string
