@@ -5,6 +5,7 @@
  */
 #include <zebra.h>
 
+#include "debug.h"
 #include "memory.h"
 #include "plist.h"
 #include "printfrr.h"
@@ -18,6 +19,8 @@
 #include "bgpd/bgp_vty.h"
 #include "bgpd/bgp_zebra.h"
 #include "bgpd/bgp_network.h"
+#include "bgpd/bgp_label.h"
+#include "bgpd/bgp_evpn_mh.h"
 
 #ifdef ENABLE_BGP_VNC
 #include "bgpd/rfapi/rfapi_backend.h"
@@ -419,6 +422,18 @@ static struct test_peer_attr test_peer_attrs[] = {
 			| PEER_FLAG_NEXTHOP_UNCHANGED
 			| PEER_FLAG_MED_UNCHANGED,
 	},
+	{
+		.cmd = "encapsulation-mpls",
+		.families[0] = {.afi = AFI_IP, .safi = SAFI_MPLS_VPN},
+		.families[1] = {.afi = AFI_IP6, .safi = SAFI_MPLS_VPN},
+		.u.flag = PEER_FLAG_CONFIG_ENCAPSULATION_MPLS,
+	},
+	{
+		.cmd = "encapsulation-srv6",
+		.families[0] = {.afi = AFI_IP, .safi = SAFI_MPLS_VPN},
+		.families[1] = {.afi = AFI_IP6, .safi = SAFI_MPLS_VPN},
+		.u.flag = PEER_FLAG_CONFIG_ENCAPSULATION_SRV6,
+	},
 	{
 		.cmd = "capability orf prefix-list send",
 		.u.flag = PEER_FLAG_ORF_PREFIX_SM,
@@ -1347,12 +1362,13 @@ static void test_peer_attr(struct test *test, struct test_peer_attr *pa)
 static void bgp_startup(void)
 {
 	cmd_init(1);
+	debug_init();
 	zlog_aux_init("NONE: ", LOG_DEBUG);
 	zprivs_preinit(&bgpd_privs);
 	zprivs_init(&bgpd_privs);
 
 	master = event_master_create(NULL);
-	nb_init(master, NULL, 0, false);
+	nb_init(master, NULL, 0, false, false);
 	bgp_master_init(master, BGP_SOCKET_SNDBUF_SIZE, list_new());
 	bgp_option_set(BGP_OPT_NO_LISTEN);
 	vrf_init(NULL, NULL, NULL, NULL);
@@ -1374,6 +1390,9 @@ static void bgp_shutdown(void)
 	bgp_route_finish();
 	bgp_route_map_terminate();
 	bgp_attr_finish();
+	bgp_labels_finish();
+	bgp_lp_finish();
+	bgp_evpn_mh_finish();
 	bgp_pthreads_finish();
 	access_list_add_hook(NULL);
 	access_list_delete_hook(NULL);
@@ -1393,6 +1412,7 @@ static void bgp_shutdown(void)
 
 	bf_free(bm->rd_idspace);
 	list_delete(&bm->bgp);
+	list_delete(&bm->addresses);
 	memset(bm, 0, sizeof(*bm));
 
 	vty_terminate();
