@@ -21,6 +21,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
+#include "debug.h"
 #include "command.h"
 #include "memory.h"
 #include "vector.h"
@@ -195,7 +196,8 @@ static void test_init(void)
 	struct cmd_element *cmd;
 
 	cmd_init(1);
-	nb_init(master, NULL, 0, false);
+	debug_init();
+	nb_init(master, NULL, 0, false, false);
 
 	install_node(&bgp_node);
 	install_node(&rip_node);
