@@ -9,21 +9,62 @@ from lib import topotest
 from lib.topogen import get_topogen
 from lib.topolog import logger
 
-# remember the last sequence number of the logging messages
-SEQ = 0
+
+class BMPSequenceContext:
+    """
+    Context class to manage BMP sequence numbers for a test run.
+    This eliminates the need for global state that can be shared across test runs.
+    """
+
+    def __init__(self, initial_seq=0):
+        self.seq = initial_seq
+
+    def get_seq(self):
+        return self.seq
+
+    def set_seq(self, seq):
+        self.seq = seq
+
+    def reset_seq(self, seq=0):
+        self.seq = seq
+
+    def display_seq(self):
+        logger.info(f"SEQ is {self.seq}")
 
 
-def bmp_reset_seq(seq_param=0):
-    global SEQ
-    SEQ = seq_param
+def bmp_reset_seq(seq_context, seq_param=0):
+    """
+    Reset the sequence number in the given context.
+
+    Args:
+        seq_context: BMPSequenceContext instance
+        seq_param: New sequence number (default 0)
+    """
+    logger.info(f"bmp_reset_seq: SEQ is now: {seq_param}")
+    seq_context.reset_seq(seq_param)
 
 
-def bmp_get_seq():
-    return SEQ
+def bmp_get_seq(seq_context):
+    """
+    Get the current sequence number from the context.
+
+    Args:
+        seq_context: BMPSequenceContext instance
+
+    Returns:
+        Current sequence number
+    """
+    return seq_context.get_seq()
 
 
-def bmp_display_seq():
-    logger.info(f"SEQ is {SEQ}")
+def bmp_display_seq(seq_context):
+    """
+    Display the current sequence number.
+
+    Args:
+        seq_context: BMPSequenceContext instance
+    """
+    seq_context.display_seq()
 
 
 def get_bmp_messages(bmp_collector, bmp_log_file):
@@ -47,13 +88,22 @@ def get_bmp_messages(bmp_collector, bmp_log_file):
     return messages
 
 
-def bmp_update_seq(bmp_collector, bmp_log_file):
-    global SEQ
+def bmp_update_seq(bmp_collector, bmp_log_file, seq_context):
+    """
+    Update the sequence number based on the BMP log file.
+
+    Args:
+        bmp_collector: BMP collector instance
+        bmp_log_file: Path to BMP log file
+        seq_context: BMPSequenceContext instance
+    """
+    logger.info("bmp_update_seq: SEQ is now: {}".format(seq_context.get_seq()))
 
     messages = get_bmp_messages(bmp_collector, bmp_log_file)
 
     if len(messages):
-        SEQ = messages[-1]["seq"]
+        seq_context.set_seq(messages[-1]["seq"])
+    logger.info("bmp_update_seq: SEQ is now: {}".format(seq_context.get_seq()))
 
 
 def bmp_update_expected_files(
@@ -123,13 +173,14 @@ def bmp_check_for_prefixes(
     expected_json_path,
     update_expected_json,
     loc_rib,
+    seq_context,
 ):
     """
     Check for the presence of the given prefixes in the BMP server logs with
     the given message type and the set policy.
 
     """
-    global SEQ
+    logger.info("SEQ is now: {}".format(seq_context.get_seq()))
 
     bmp_log_file = f"{bmp_log_folder}/bmp.log"
     # we care only about the new messages
@@ -138,7 +189,7 @@ def bmp_check_for_prefixes(
         for m in sorted(
             get_bmp_messages(bmp_collector, bmp_log_file), key=lambda d: d["seq"]
         )
-        if m["seq"] > SEQ
+        if m["seq"] > seq_context.get_seq()
     ]
 
     # create empty initial files
@@ -199,34 +250,60 @@ def bmp_check_for_peer_message(
     bmp_log_type,
     bmp_collector,
     bmp_log_file,
+    seq_context,
     is_rd_instance=False,
     peer_bgp_id=None,
     peer_distinguisher=None,
+    bgp_open_as=None,
+    bgp_open_bgp_id=None,
 ):
     """
     Check for the presence of a peer up message for the peer
     """
-    global SEQ
-    last_seq = SEQ
+    last_seq = seq_context.get_seq()
 
+    logger.info(
+        "bmp_check_for_peer_message: SEQ is now: {}".format(seq_context.get_seq())
+    )
     # we care only about the new messages
     messages = [
         m
         for m in sorted(
             get_bmp_messages(bmp_collector, bmp_log_file), key=lambda d: d["seq"]
         )
-        if m["seq"] > SEQ
+        if m["seq"] > seq_context.get_seq()
     ]
 
     # get the list of pairs (prefix, policy, seq) for the given message type
     peers = []
     for m in messages:
+        logger.info("LOOKING AT MESSAGE:")
+        logger.info("m: {}".format(m))
         if is_rd_instance and m["peer_distinguisher"] == "0:0":
             continue
         if peer_distinguisher and m["peer_distinguisher"] != peer_distinguisher:
             continue
         if peer_bgp_id and m["peer_bgp_id"] != peer_bgp_id:
             continue
+        if bgp_open_as:
+            if not m.get("open_tx", {}).get("my_as", None):
+                continue
+            if m["open_tx"]["my_as"] != bgp_open_as:
+                continue
+            if not m.get("open_rx", {}).get("my_as", None):
+                continue
+            if m["open_rx"]["my_as"] != bgp_open_as:
+                continue
+
+        if bgp_open_bgp_id:
+            if not m.get("open_tx", {}).get("bgp_id", None):
+                continue
+            if m["open_tx"]["bgp_id"] != bgp_open_bgp_id:
+                continue
+            if not m.get("open_rx", {}).get("bgp_id", None):
+                continue
+            if m["open_rx"]["bgp_id"] != bgp_open_bgp_id:
+                continue
         if (
             "peer_ip" in m.keys()
             and m["peer_ip"] != "0.0.0.0"
@@ -242,8 +319,8 @@ def bmp_check_for_peer_message(
     for ep in expected_peers:
         for _ip, _seq in peers:
             if ep == _ip:
-                msg = "The peer {} is present in the {} log messages."
-                logger.debug(msg.format(ep, bmp_log_type))
+                msg = "The peer {} is present in the {} log messages sequence is {}."
+                logger.debug(msg.format(ep, bmp_log_type, _seq))
                 if _seq > last_seq:
                     last_seq = _seq
                 break
@@ -252,5 +329,8 @@ def bmp_check_for_peer_message(
             logger.debug(msg.format(ep, bmp_log_type))
             return False
 
-    SEQ = last_seq
+    seq_context.set_seq(last_seq)
+    logger.info(
+        "bmp_check_for_peer_message: SEQ is now: {}".format(seq_context.get_seq())
+    )
     return True
