@@ -21,8 +21,6 @@ import sys
 import time
 import pytest
 import platform
-import functools
-from lib import topotest
 from copy import deepcopy
 
 
@@ -541,16 +539,6 @@ def test_RT_verification_auto_p0(request):
     result = create_vrf_cfg(tgen, topo, input_dict=input_dict_vni)
     assert result is True, "Testcase {} :Failed \n Error: {}".format(tc_name, result)
 
-    expected = {"numL3Vnis": 0}
-    test_func = functools.partial(
-        topotest.router_json_cmp,
-        tgen.gears["e1"],
-        "show bgp l2vpn evpn vni json",
-        expected,
-    )
-    _, result = topotest.run_and_expect(test_func, None, count=5, wait=3)
-    assert result is None, "Testcase {} :Failed \n Error: {}".format(tc_name, result)
-
     input_dict_2 = {}
     for dut in ["e1"]:
         temp = {dut: {"bgp": []}}
