@@ -191,6 +191,11 @@ static void connected_remove_kernel_for_connected(afi_t afi, safi_t safi, struct
 	rib_dest_t *dest;
 	struct route_table *table = zebra_vrf_table(afi, SAFI_UNICAST, zvrf->vrf->vrf_id);
 
+	/*
+	 * Needs to be early as that the actual route_node may not exist yet
+	 */
+	rib_meta_queue_early_route_cleanup(p, ZEBRA_ROUTE_KERNEL);
+
 	if (!table)
 		return;
 
@@ -295,7 +300,7 @@ void connected_up(struct interface *ifp, struct connected *ifc)
 	 * pretend like the route is offloaded so everything
 	 * else will work
 	 */
-	if (zrouter.asic_offloaded)
+	if (zrouter.zav.asic_offloaded)
 		flags |= ZEBRA_FLAG_OFFLOADED;
 
 	/*
@@ -361,7 +366,7 @@ void connected_add_ipv4(struct interface *ifp, int flags,
 	struct prefix_ipv4 *p;
 	struct connected *ifc;
 
-	if (ipv4_martian(addr))
+	if (!ipv4_ietf_unicast_valid(addr))
 		return;
 
 	/* Make connected structure. */
