@@ -1,25 +1,11 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * Interface looking up by ioctl ().
  * Copyright (C) 1997, 98 Kunihiro Ishiguro
- *
- * This file is part of GNU Zebra.
- *
- * GNU Zebra is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
- * later version.
- *
- * GNU Zebra is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <zebra.h>
+#include <sys/ioctl.h>
 
 #ifdef OPEN_BSD
 
@@ -249,7 +235,6 @@ static int if_getaddrs(void)
 			mask = (struct sockaddr_in6 *)ifap->ifa_netmask;
 			prefixlen = ip6_masklen(mask->sin6_addr);
 
-#if defined(KAME)
 			if (IN6_IS_ADDR_LINKLOCAL(&addr->sin6_addr)) {
 				addr->sin6_scope_id =
 					ntohs(*(uint16_t *)&addr->sin6_addr
@@ -257,7 +242,6 @@ static int if_getaddrs(void)
 				addr->sin6_addr.s6_addr[2] =
 					addr->sin6_addr.s6_addr[3] = 0;
 			}
-#endif
 
 			connected_add_ipv6(ifp, flags, &addr->sin6_addr, NULL,
 					   prefixlen, NULL, METRIC_MAX);
@@ -310,6 +294,8 @@ void interface_list(struct zebra_ns *zns)
 	   /proc/net/if_inet6. */
 	ifaddr_proc_ipv6();
 #endif /* HAVE_PROC_NET_IF_INET6 */
+
+	zebra_dplane_startup_stage(zns, ZEBRA_DPLANE_INTERFACES_READ);
 }
 
 #endif /* OPEN_BSD */
