@@ -221,6 +221,8 @@ static void netlink_determine_zebra_iftype(const char *kind,
 		*zif_type = ZEBRA_IF_BOND;
 	else if (strcmp(kind, "gre") == 0)
 		*zif_type = ZEBRA_IF_GRE;
+	else if (strcmp(kind, "dummy") == 0)
+		*zif_type = ZEBRA_IF_DUMMY;
 }
 
 static void netlink_vrf_change(struct nlmsghdr *h, struct rtattr *tb,
@@ -576,6 +578,7 @@ static void netlink_interface_update_l2info(struct zebra_dplane_ctx *ctx,
 	case ZEBRA_IF_MACVLAN:
 	case ZEBRA_IF_VETH:
 	case ZEBRA_IF_BOND:
+	case ZEBRA_IF_DUMMY:
 		break;
 	}
 }
@@ -635,6 +638,9 @@ netlink_bridge_vxlan_vlan_vni_map_update(struct zebra_dplane_ctx *ctx,
 	if (count) {
 		vniarray->count = count;
 		dplane_ctx_set_ifp_vxlan_vni_array(ctx, vniarray);
+	} else if (vniarray) {
+		/* Free allocated memory if count is 0 */
+		XFREE(MTYPE_TMP, vniarray);
 	}
 	return 0;
 }
@@ -702,6 +708,9 @@ static void netlink_bridge_vlan_update(struct zebra_dplane_ctx *ctx,
 	if (count) {
 		bvarray->count = count;
 		dplane_ctx_set_ifp_bridge_vlan_info_array(ctx, bvarray);
+	} else if (bvarray) {
+		/* Free allocated memory if count is 0 */
+		XFREE(MTYPE_TMP, bvarray);
 	}
 }
 
@@ -1269,8 +1278,9 @@ int netlink_link_change(struct nlmsghdr *h, ns_id_t ns_id, int startup)
 
 	if (!(h->nlmsg_type == RTM_NEWLINK || h->nlmsg_type == RTM_DELLINK)) {
 		/* If this is not link add/delete message so print warning. */
-		zlog_debug("%s: wrong kernel message %s", __func__,
-			   nl_msg_type_to_str(h->nlmsg_type));
+		if (IS_ZEBRA_DEBUG_KERNEL)
+			zlog_debug("%s: wrong kernel message %s", __func__,
+				   nl_msg_type_to_str(h->nlmsg_type));
 		return 0;
 	}
 
@@ -1746,8 +1756,13 @@ int netlink_vlan_change(struct nlmsghdr *h, ns_id_t ns_id, int startup)
 				   bvm->ifindex, ns_id);
 
 		dplane_provider_enqueue_to_zebra(ctx);
-	} else
+	} else {
+		if (vlan_array) {
+			/* Free allocated memory if count is 0 */
+			XFREE(MTYPE_VLAN_CHANGE_ARR, vlan_array);
+		}
 		dplane_ctx_fini(&ctx);
+	}
 
 
 	return 0;
