@@ -46,12 +46,11 @@ DEFINE_MTYPE_STATIC(ZEBRA, ZEVPN_VTEP, "VNI remote VTEP");
 /* PMSI strings. */
 #define VXLAN_FLOOD_STR_NO_INFO "-"
 #define VXLAN_FLOOD_STR_DEFAULT VXLAN_FLOOD_STR_NO_INFO
-static const struct message zvtep_flood_str[] = {
-	{VXLAN_FLOOD_DISABLED, VXLAN_FLOOD_STR_NO_INFO},
-	{VXLAN_FLOOD_PIM_SM, "PIM-SM"},
-	{VXLAN_FLOOD_HEAD_END_REPL, "HER"},
-	{0}
-};
+static const struct message zvtep_flood_str[] = { { VXLAN_FLOOD_DISABLED, VXLAN_FLOOD_STR_NO_INFO },
+						  { VXLAN_FLOOD_PIM_SM, "PIM-SM" },
+						  { VXLAN_FLOOD_HEAD_END_REPL, "HER" },
+						  { VXLAN_FLOOD_INHERIT_GLOBAL, "Inherit Global" },
+						  { 0 } };
 
 int advertise_gw_macip_enabled(struct zebra_evpn *zevpn)
 {
@@ -1303,16 +1302,22 @@ int zebra_evpn_vtep_uninstall(struct zebra_evpn *zevpn, struct in_addr *vtep_ip)
  * Install or uninstall flood entries in the kernel corresponding to
  * remote VTEPs. This is invoked upon change to BUM handling.
  */
-void zebra_evpn_handle_flooding_remote_vteps(struct hash_bucket *bucket,
-					     void *zvrf)
+void zebra_evpn_handle_flooding_remote_vteps(struct hash_bucket *bucket, void *args[])
 {
 	struct zebra_evpn *zevpn;
 	struct zebra_vtep *zvtep;
+	vni_t vni = *(vni_t *)args[0];
 
 	zevpn = (struct zebra_evpn *)bucket->data;
 	if (!zevpn)
 		return;
 
+	/* If this is a per-VNI flooding change, then check if this is the right VNI.
+	 * Ignore if it's a global change.
+	 */
+	if (vni != VNI_MAX && zevpn->vni != vni)
+		return;
+
 	for (zvtep = zevpn->vteps; zvtep; zvtep = zvtep->next) {
 		if (is_vxlan_flooding_head_end())
 			zebra_evpn_vtep_install(zevpn, zvtep);
@@ -1513,6 +1518,12 @@ void zebra_evpn_rem_macip_del(vni_t vni, const struct ethaddr *macaddr,
 	struct zebra_vrf *zvrf;
 	char buf1[INET6_ADDRSTRLEN];
 
+	if (!macaddr) {
+		if (IS_ZEBRA_DEBUG_VXLAN)
+			zlog_debug("NULL MAC address provided for remote MACIP DEL VNI %u", vni);
+		return;
+	}
+
 	/* Locate EVPN hash entry - expected to exist. */
 	zevpn = zebra_evpn_lookup(vni);
 	if (!zevpn) {
