@@ -1,23 +1,7 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /* Zebra Mlag Code.
  * Copyright (C) 2018 Cumulus Networks, Inc.
  *                    Donald Sharp
- *
- * This file is part of FRR.
- *
- * FRR is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
- * later version.
- *
- * FRR is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with FRR; see the file COPYING.  If not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
  */
 #include "zebra.h"
 
@@ -52,8 +36,8 @@ uint8_t mlag_rd_buffer[ZEBRA_MLAG_BUF_LIMIT];
 static bool test_mlag_in_progress;
 
 static int zebra_mlag_signal_write_thread(void);
-static void zebra_mlag_terminate_pthread(struct thread *event);
-static void zebra_mlag_post_data_from_main_thread(struct thread *thread);
+static void zebra_mlag_terminate_pthread(struct event *event);
+static void zebra_mlag_post_data_from_main_thread(struct event *thread);
 static void zebra_mlag_publish_process_state(struct zserv *client,
 					     zebra_message_types_t msg_type);
 
@@ -130,8 +114,8 @@ void zebra_mlag_process_mlag_data(uint8_t *data, uint32_t len)
 	 * additional four bytes are for message type
 	 */
 	stream_putl_at(s, 0, msg_type);
-	thread_add_event(zrouter.master, zebra_mlag_post_data_from_main_thread,
-			 s, 0, NULL);
+	event_add_event(zrouter.master, zebra_mlag_post_data_from_main_thread,
+			s, 0, NULL);
 }
 
 /**********************End of MLAG Interaction********************************/
@@ -148,7 +132,7 @@ void zebra_mlag_process_mlag_data(uint8_t *data, uint32_t len)
  * This thread reads the clients data from the Global queue and encodes with
  * protobuf and pass on to the MLAG socket.
  */
-static void zebra_mlag_client_msg_handler(struct thread *event)
+static void zebra_mlag_client_msg_handler(struct event *event)
 {
 	struct stream *s;
 	uint32_t wr_count = 0;
@@ -189,9 +173,9 @@ static void zebra_mlag_client_msg_handler(struct thread *event)
 			 * main thread.
 			 */
 			if (msg_type == MLAG_DEREGISTER) {
-				thread_add_event(zrouter.master,
-						 zebra_mlag_terminate_pthread,
-						 NULL, 0, NULL);
+				event_add_event(zrouter.master,
+						zebra_mlag_terminate_pthread,
+						NULL, 0, NULL);
 			}
 		}
 
@@ -253,9 +237,9 @@ static int zebra_mlag_signal_write_thread(void)
 	 * during Zebra Init/after MLAG thread is destroyed.
 	 * so it is safe to use without any locking
 	 */
-	thread_add_event(zrouter.mlag_info.th_master,
-			 zebra_mlag_client_msg_handler, NULL, 0,
-			 &zrouter.mlag_info.t_write);
+	event_add_event(zrouter.mlag_info.th_master,
+			zebra_mlag_client_msg_handler, NULL, 0,
+			&zrouter.mlag_info.t_write);
 	return 0;
 }
 
@@ -295,8 +279,8 @@ static void zebra_mlag_publish_process_state(struct zserv *client,
 	s = stream_new(ZEBRA_HEADER_SIZE + ZEBRA_MLAG_METADATA_LEN);
 	stream_putl(s, ZEBRA_MLAG_MSG_BCAST);
 	zclient_create_header(s, msg_type, VRF_DEFAULT);
-	thread_add_event(zrouter.master, zebra_mlag_post_data_from_main_thread,
-			 s, 0, NULL);
+	event_add_event(zrouter.master, zebra_mlag_post_data_from_main_thread,
+			s, 0, NULL);
 }
 
 /**************************End of Multi-entrant Apis**************************/
@@ -308,11 +292,10 @@ static void zebra_mlag_publish_process_state(struct zserv *client,
  * main thread, because for that access was needed for clients list.
  * so instead of forcing the locks, messages will be posted from main thread.
  */
-static void zebra_mlag_post_data_from_main_thread(struct thread *thread)
+static void zebra_mlag_post_data_from_main_thread(struct event *thread)
 {
-	struct stream *s = THREAD_ARG(thread);
+	struct stream *s = EVENT_ARG(thread);
 	struct stream *zebra_s = NULL;
-	struct listnode *node;
 	struct zserv *client;
 	uint32_t msg_type = 0;
 	uint32_t msg_len = 0;
@@ -327,7 +310,7 @@ static void zebra_mlag_post_data_from_main_thread(struct thread *thread)
 			__func__, msg_type);
 
 	msg_len = s->endp - ZEBRA_MLAG_METADATA_LEN;
-	for (ALL_LIST_ELEMENTS_RO(zrouter.client_list, node, client)) {
+	frr_each (zserv_client_list, &zrouter.client_list, client) {
 		if (client->mlag_updates_interested == true) {
 			if (msg_type != ZEBRA_MLAG_MSG_BCAST
 			    && !CHECK_FLAG(client->mlag_reg_mask1,
@@ -354,8 +337,6 @@ static void zebra_mlag_post_data_from_main_thread(struct thread *thread)
 		}
 	}
 
-	stream_free(s);
-	return;
 stream_failure:
 	stream_free(s);
 	if (zebra_s)
@@ -392,7 +373,7 @@ static void zebra_mlag_spawn_pthread(void)
  * all clients are un-registered for MLAG Updates, terminate the
  * MLAG write thread
  */
-static void zebra_mlag_terminate_pthread(struct thread *event)
+static void zebra_mlag_terminate_pthread(struct event *event)
 {
 	if (IS_ZEBRA_DEBUG_MLAG)
 		zlog_debug("Zebra MLAG write thread terminate called");
@@ -645,6 +626,8 @@ void zebra_mlag_init(void)
 
 void zebra_mlag_terminate(void)
 {
+	stream_fifo_free(zrouter.mlag_info.mlag_fifo);
+	zrouter.mlag_info.mlag_fifo = NULL;
 }
 
 
@@ -888,7 +871,14 @@ int zebra_mlag_protobuf_encode_client_data(struct stream *s, uint32_t *msg_type)
 		if (cleanup)
 			return -1;
 	} break;
-	default:
+	case MLAG_REGISTER:
+	case MLAG_DEREGISTER:
+	case MLAG_STATUS_UPDATE:
+	case MLAG_DUMP:
+	case MLAG_PIM_CFG_DUMP:
+	case MLAG_VXLAN_UPDATE:
+	case MLAG_PEER_FRR_STATUS:
+	case MLAG_MSG_NONE:
 		break;
 	}
 
@@ -994,8 +984,7 @@ int zebra_mlag_protobuf_decode_message(struct stream *s, uint8_t *data,
 			/* No Batching */
 			stream_putw(s, MLAG_MSG_NO_BATCH);
 			/* Actual Data */
-			zebra_fill_protobuf_msg(s, msg->peerlink,
-						INTERFACE_NAMSIZ);
+			zebra_fill_protobuf_msg(s, msg->peerlink, IFNAMSIZ);
 			stream_putl(s, msg->my_role);
 			stream_putl(s, msg->peer_state);
 			zebra_mlag_status_update__free_unpacked(msg, NULL);
@@ -1043,9 +1032,9 @@ int zebra_mlag_protobuf_decode_message(struct stream *s, uint8_t *data,
 			stream_putl(s, msg->vrf_id);
 			if (msg->owner_id == MLAG_OWNER_INTERFACE)
 				zebra_fill_protobuf_msg(s, msg->intf_name,
-							INTERFACE_NAMSIZ);
+							IFNAMSIZ);
 			else
-				stream_put(s, NULL, INTERFACE_NAMSIZ);
+				stream_put(s, NULL, IFNAMSIZ);
 			zebra_mlag_mroute_add__free_unpacked(msg, NULL);
 		} break;
 		case ZEBRA_MLAG__HEADER__MESSAGE_TYPE__ZEBRA_MLAG_MROUTE_DEL: {
@@ -1070,9 +1059,9 @@ int zebra_mlag_protobuf_decode_message(struct stream *s, uint8_t *data,
 			stream_putl(s, msg->vrf_id);
 			if (msg->owner_id == MLAG_OWNER_INTERFACE)
 				zebra_fill_protobuf_msg(s, msg->intf_name,
-							INTERFACE_NAMSIZ);
+							IFNAMSIZ);
 			else
-				stream_put(s, NULL, INTERFACE_NAMSIZ);
+				stream_put(s, NULL, IFNAMSIZ);
 			zebra_mlag_mroute_del__free_unpacked(msg, NULL);
 		} break;
 		case ZEBRA_MLAG__HEADER__MESSAGE_TYPE__ZEBRA_MLAG_MROUTE_ADD_BULK: {
@@ -1094,8 +1083,7 @@ int zebra_mlag_protobuf_decode_message(struct stream *s, uint8_t *data,
 
 			/* Actual Data */
 			for (i = 0; i < Bulk_msg->n_mroute_add; i++) {
-				if (STREAM_SIZE(s)
-				    < VRF_NAMSIZ + 22 + INTERFACE_NAMSIZ) {
+				if (STREAM_SIZE(s) < VRF_NAMSIZ + 22 + IFNAMSIZ) {
 					zlog_warn(
 						"We have received more messages than we can parse at this point in time: %zu",
 						Bulk_msg->n_mroute_add);
@@ -1114,11 +1102,11 @@ int zebra_mlag_protobuf_decode_message(struct stream *s, uint8_t *data,
 				stream_putc(s, msg->am_i_dual_active);
 				stream_putl(s, msg->vrf_id);
 				if (msg->owner_id == MLAG_OWNER_INTERFACE)
-					zebra_fill_protobuf_msg(
-						s, msg->intf_name,
-						INTERFACE_NAMSIZ);
+					zebra_fill_protobuf_msg(s,
+								msg->intf_name,
+								IFNAMSIZ);
 				else
-					stream_put(s, NULL, INTERFACE_NAMSIZ);
+					stream_put(s, NULL, IFNAMSIZ);
 			}
 
 			stream_putw_at(s, length_spot, i + 1);
@@ -1145,8 +1133,7 @@ int zebra_mlag_protobuf_decode_message(struct stream *s, uint8_t *data,
 
 			/* Actual Data */
 			for (i = 0; i < Bulk_msg->n_mroute_del; i++) {
-				if (STREAM_SIZE(s)
-				    < VRF_NAMSIZ + 16 + INTERFACE_NAMSIZ) {
+				if (STREAM_SIZE(s) < VRF_NAMSIZ + 16 + IFNAMSIZ) {
 					zlog_warn(
 						"We have received more messages than we can parse at this time");
 					break;
@@ -1161,11 +1148,11 @@ int zebra_mlag_protobuf_decode_message(struct stream *s, uint8_t *data,
 				stream_putl(s, msg->owner_id);
 				stream_putl(s, msg->vrf_id);
 				if (msg->owner_id == MLAG_OWNER_INTERFACE)
-					zebra_fill_protobuf_msg(
-						s, msg->intf_name,
-						INTERFACE_NAMSIZ);
+					zebra_fill_protobuf_msg(s,
+								msg->intf_name,
+								IFNAMSIZ);
 				else
-					stream_put(s, NULL, INTERFACE_NAMSIZ);
+					stream_put(s, NULL, IFNAMSIZ);
 			}
 
 			stream_putw_at(s, length_spot, i + 1);
